# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/yamcsManagement/yamcsManagement.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/yamcsManagement/yamcsManagement.proto',
  package='yamcs.protobuf.yamcsManagement',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobuf'),
  serialized_pb=_b('\n4yamcs/protobuf/yamcsManagement/yamcsManagement.proto\x12\x1eyamcs.protobuf.yamcsManagement\x1a\x1ayamcs/protobuf/yamcs.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\"Q\n\x0eYamcsInstances\x12?\n\x08instance\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.YamcsInstance\"\x8a\x03\n\rYamcsInstance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0fmissionDatabase\x18\x03 \x01(\x0b\x32#.yamcs.protobuf.mdb.MissionDatabase\x12@\n\tprocessor\x18\x04 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\x12J\n\x05state\x18\x0b \x01(\x0e\x32;.yamcs.protobuf.yamcsManagement.YamcsInstance.InstanceState\x12\x14\n\x0c\x66\x61ilureCause\x18\t \x01(\t\x12\x13\n\x0bmissionTime\x18\n \x01(\t\"t\n\rInstanceState\x12\x0b\n\x07OFFLINE\x10\x00\x12\x10\n\x0cINITIALIZING\x10\x01\x12\x0f\n\x0bINITIALIZED\x10\x02\x12\x0c\n\x08STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\"\xa8\x03\n\rProcessorInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04spec\x18\x04 \x01(\t\x12\x0f\n\x07\x63reator\x18\x05 \x01(\t\x12\x11\n\thasAlarms\x18\x06 \x01(\x08\x12\x15\n\rhasCommanding\x18\x07 \x01(\x08\x12;\n\x05state\x18\x08 \x01(\x0e\x32,.yamcs.protobuf.yamcsManagement.ServiceState\x12\x34\n\rreplayRequest\x18\t \x01(\x0b\x32\x1d.yamcs.protobuf.ReplayRequest\x12=\n\x0breplayState\x18\n \x01(\x0e\x32(.yamcs.protobuf.ReplayStatus.ReplayState\x12<\n\x07service\x18\x10 \x03(\x0b\x32+.yamcs.protobuf.yamcsManagement.ServiceInfo\x12\x12\n\npersistent\x18\x11 \x01(\x08\x12\x0c\n\x04time\x18\x12 \x01(\t\x12\x0e\n\x06replay\x18\x13 \x01(\x08\"\x8c\x02\n\nClientInfo\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x17\n\x0f\x61pplicationName\x18\x04 \x01(\t\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x15\n\rprocessorName\x18\x05 \x01(\t\x12\x45\n\x05state\x18\x06 \x01(\x0e\x32\x36.yamcs.protobuf.yamcsManagement.ClientInfo.ClientState\x12\x11\n\tloginTime\x18\x08 \x01(\x03\x12\x14\n\x0cloginTimeUTC\x18\t \x01(\t\".\n\x0b\x43lientState\x12\r\n\tCONNECTED\x10\x00\x12\x10\n\x0c\x44ISCONNECTED\x10\x01\"3\n\x13ObjectPrivilegeInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06object\x18\x02 \x03(\t\"\xd3\x01\n\x08UserInfo\x12\r\n\x05login\x18\x01 \x01(\t\x12>\n\nclientInfo\x18\x02 \x03(\x0b\x32*.yamcs.protobuf.yamcsManagement.ClientInfo\x12\x17\n\x0fsystemPrivilege\x18\x0b \x03(\t\x12L\n\x0fobjectPrivilege\x18\x0c \x03(\x0b\x32\x33.yamcs.protobuf.yamcsManagement.ObjectPrivilegeInfo\x12\x11\n\tsuperuser\x18\r \x01(\x08\"\xbf\x01\n\x0cTmStatistics\x12\x12\n\npacketName\x18\x01 \x01(\t\x12\x17\n\x0freceivedPackets\x18\x02 \x01(\x03\x12\x14\n\x0clastReceived\x18\x03 \x01(\x03\x12\x17\n\x0flastReceivedUTC\x18\x08 \x01(\t\x12\x16\n\x0elastPacketTime\x18\x04 \x01(\x03\x12\x19\n\x11lastPacketTimeUTC\x18\x07 \x01(\t\x12 \n\x18subscribedParameterCount\x18\x06 \x01(\x05\"\xa2\x01\n\nStatistics\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x16\n\x0eyProcessorName\x18\x02 \x01(\t\x12=\n\x07tmstats\x18\x03 \x03(\x0b\x32,.yamcs.protobuf.yamcsManagement.TmStatistics\x12\x13\n\x0blastUpdated\x18\x04 \x01(\x03\x12\x16\n\x0elastUpdatedUTC\x18\x05 \x01(\t\"\x9d\x02\n\x1aProcessorManagementRequest\x12W\n\toperation\x18\x01 \x01(\x0e\x32\x44.yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.Operation\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12\x10\n\x08\x63lientId\x18\x06 \x03(\x05\x12\x19\n\npersistent\x18\x07 \x01(\x08:\x05\x66\x61lse\";\n\tOperation\x12\x14\n\x10\x43REATE_PROCESSOR\x10\x00\x12\x18\n\x14\x43ONNECT_TO_PROCESSOR\x10\x01\"\x85\x02\n\x10ProcessorRequest\x12M\n\toperation\x18\x01 \x01(\x0e\x32:.yamcs.protobuf.yamcsManagement.ProcessorRequest.Operation\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08seekTime\x18\x04 \x01(\x03\x12\x30\n\x0breplaySpeed\x18\x05 \x01(\x0b\x32\x1b.yamcs.protobuf.ReplaySpeed\">\n\tOperation\x12\t\n\x05PAUSE\x10\x02\x12\n\n\x06RESUME\x10\x03\x12\x08\n\x04SEEK\x10\x04\x12\x10\n\x0c\x43HANGE_SPEED\x10\x05\"\xd6\x01\n\x08LinkInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04spec\x18\x04 \x01(\t\x12\x12\n\x06stream\x18\x05 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x0e\n\x06status\x18\x07 \x01(\t\x12\x15\n\tdataCount\x18\x08 \x01(\x03\x42\x02\x18\x01\x12\x13\n\x0b\x64\x61taInCount\x18\n \x01(\x03\x12\x14\n\x0c\x64\x61taOutCount\x18\x0b \x01(\x03\x12\x16\n\x0e\x64\x65tailedStatus\x18\t \x01(\t\"\xbc\x01\n\tLinkEvent\x12<\n\x04type\x18\x01 \x01(\x0e\x32..yamcs.protobuf.yamcsManagement.LinkEvent.Type\x12:\n\x08linkInfo\x18\x02 \x01(\x0b\x32(.yamcs.protobuf.yamcsManagement.LinkInfo\"5\n\x04Type\x12\x0e\n\nREGISTERED\x10\x01\x12\x10\n\x0cUNREGISTERED\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\"\x90\x01\n\x0bServiceInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\x05state\x18\x03 \x01(\x0e\x32,.yamcs.protobuf.yamcsManagement.ServiceState\x12\x11\n\tclassName\x18\x04 \x01(\t\x12\x11\n\tprocessor\x18\x05 \x01(\t*\\\n\x0cServiceState\x12\x07\n\x03NEW\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08STOPPING\x10\x03\x12\x0e\n\nTERMINATED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x42\x14\n\x12org.yamcs.protobuf')
  ,
  dependencies=[yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,])

_SERVICESTATE = _descriptor.EnumDescriptor(
  name='ServiceState',
  full_name='yamcs.protobuf.yamcsManagement.ServiceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TERMINATED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3057,
  serialized_end=3149,
)
_sym_db.RegisterEnumDescriptor(_SERVICESTATE)

ServiceState = enum_type_wrapper.EnumTypeWrapper(_SERVICESTATE)
NEW = 0
STARTING = 1
RUNNING = 2
STOPPING = 3
TERMINATED = 4
FAILED = 5


_YAMCSINSTANCE_INSTANCESTATE = _descriptor.EnumDescriptor(
  name='InstanceState',
  full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.InstanceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFFLINE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=508,
  serialized_end=624,
)
_sym_db.RegisterEnumDescriptor(_YAMCSINSTANCE_INSTANCESTATE)

_CLIENTINFO_CLIENTSTATE = _descriptor.EnumDescriptor(
  name='ClientState',
  full_name='yamcs.protobuf.yamcsManagement.ClientInfo.ClientState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONNECTED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCONNECTED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1276,
  serialized_end=1322,
)
_sym_db.RegisterEnumDescriptor(_CLIENTINFO_CLIENTSTATE)

_PROCESSORMANAGEMENTREQUEST_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.Operation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATE_PROCESSOR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECT_TO_PROCESSOR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2177,
  serialized_end=2236,
)
_sym_db.RegisterEnumDescriptor(_PROCESSORMANAGEMENTREQUEST_OPERATION)

_PROCESSORREQUEST_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.Operation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PAUSE', index=0, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESUME', index=1, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEEK', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_SPEED', index=3, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2438,
  serialized_end=2500,
)
_sym_db.RegisterEnumDescriptor(_PROCESSORREQUEST_OPERATION)

_LINKEVENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.yamcsManagement.LinkEvent.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REGISTERED', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNREGISTERED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATED', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2855,
  serialized_end=2908,
)
_sym_db.RegisterEnumDescriptor(_LINKEVENT_TYPE)


_YAMCSINSTANCES = _descriptor.Descriptor(
  name='YamcsInstances',
  full_name='yamcs.protobuf.yamcsManagement.YamcsInstances',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.YamcsInstances.instance', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=227,
)


_YAMCSINSTANCE = _descriptor.Descriptor(
  name='YamcsInstance',
  full_name='yamcs.protobuf.yamcsManagement.YamcsInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missionDatabase', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.missionDatabase', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.processor', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.state', index=3,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureCause', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.failureCause', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missionTime', full_name='yamcs.protobuf.yamcsManagement.YamcsInstance.missionTime', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _YAMCSINSTANCE_INSTANCESTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=624,
)


_PROCESSORINFO = _descriptor.Descriptor(
  name='ProcessorInfo',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.spec', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.creator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasAlarms', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.hasAlarms', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasCommanding', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.hasCommanding', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.state', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replayRequest', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replayRequest', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replayState', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replayState', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.service', index=10,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.persistent', index=11,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.time', index=12,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replay', full_name='yamcs.protobuf.yamcsManagement.ProcessorInfo.replay', index=13,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=1051,
)


_CLIENTINFO = _descriptor.Descriptor(
  name='ClientInfo',
  full_name='yamcs.protobuf.yamcsManagement.ClientInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.id', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.username', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='applicationName', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.applicationName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.instance', index=3,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processorName', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.processorName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loginTime', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.loginTime', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loginTimeUTC', full_name='yamcs.protobuf.yamcsManagement.ClientInfo.loginTimeUTC', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTINFO_CLIENTSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1322,
)


_OBJECTPRIVILEGEINFO = _descriptor.Descriptor(
  name='ObjectPrivilegeInfo',
  full_name='yamcs.protobuf.yamcsManagement.ObjectPrivilegeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.ObjectPrivilegeInfo.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='yamcs.protobuf.yamcsManagement.ObjectPrivilegeInfo.object', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1324,
  serialized_end=1375,
)


_USERINFO = _descriptor.Descriptor(
  name='UserInfo',
  full_name='yamcs.protobuf.yamcsManagement.UserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='login', full_name='yamcs.protobuf.yamcsManagement.UserInfo.login', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientInfo', full_name='yamcs.protobuf.yamcsManagement.UserInfo.clientInfo', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='systemPrivilege', full_name='yamcs.protobuf.yamcsManagement.UserInfo.systemPrivilege', index=2,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectPrivilege', full_name='yamcs.protobuf.yamcsManagement.UserInfo.objectPrivilege', index=3,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='superuser', full_name='yamcs.protobuf.yamcsManagement.UserInfo.superuser', index=4,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1378,
  serialized_end=1589,
)


_TMSTATISTICS = _descriptor.Descriptor(
  name='TmStatistics',
  full_name='yamcs.protobuf.yamcsManagement.TmStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packetName', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.packetName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receivedPackets', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.receivedPackets', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastReceived', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.lastReceived', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastReceivedUTC', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.lastReceivedUTC', index=3,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastPacketTime', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.lastPacketTime', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastPacketTimeUTC', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.lastPacketTimeUTC', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribedParameterCount', full_name='yamcs.protobuf.yamcsManagement.TmStatistics.subscribedParameterCount', index=6,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1592,
  serialized_end=1783,
)


_STATISTICS = _descriptor.Descriptor(
  name='Statistics',
  full_name='yamcs.protobuf.yamcsManagement.Statistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.Statistics.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yProcessorName', full_name='yamcs.protobuf.yamcsManagement.Statistics.yProcessorName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmstats', full_name='yamcs.protobuf.yamcsManagement.Statistics.tmstats', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastUpdated', full_name='yamcs.protobuf.yamcsManagement.Statistics.lastUpdated', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastUpdatedUTC', full_name='yamcs.protobuf.yamcsManagement.Statistics.lastUpdatedUTC', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1786,
  serialized_end=1948,
)


_PROCESSORMANAGEMENTREQUEST = _descriptor.Descriptor(
  name='ProcessorManagementRequest',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.config', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientId', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.clientId', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.yamcsManagement.ProcessorManagementRequest.persistent', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSORMANAGEMENTREQUEST_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1951,
  serialized_end=2236,
)


_PROCESSORREQUEST = _descriptor.Descriptor(
  name='ProcessorRequest',
  full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.instance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seekTime', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.seekTime', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replaySpeed', full_name='yamcs.protobuf.yamcsManagement.ProcessorRequest.replaySpeed', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSORREQUEST_OPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2239,
  serialized_end=2500,
)


_LINKINFO = _descriptor.Descriptor(
  name='LinkInfo',
  full_name='yamcs.protobuf.yamcsManagement.LinkInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.spec', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.stream', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.disabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.status', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataCount', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.dataCount', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataInCount', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.dataInCount', index=8,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataOutCount', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.dataOutCount', index=9,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detailedStatus', full_name='yamcs.protobuf.yamcsManagement.LinkInfo.detailedStatus', index=10,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2503,
  serialized_end=2717,
)


_LINKEVENT = _descriptor.Descriptor(
  name='LinkEvent',
  full_name='yamcs.protobuf.yamcsManagement.LinkEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.yamcsManagement.LinkEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linkInfo', full_name='yamcs.protobuf.yamcsManagement.LinkEvent.linkInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LINKEVENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2720,
  serialized_end=2908,
)


_SERVICEINFO = _descriptor.Descriptor(
  name='ServiceInfo',
  full_name='yamcs.protobuf.yamcsManagement.ServiceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='className', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.className', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.yamcsManagement.ServiceInfo.processor', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2911,
  serialized_end=3055,
)

_YAMCSINSTANCES.fields_by_name['instance'].message_type = _YAMCSINSTANCE
_YAMCSINSTANCE.fields_by_name['missionDatabase'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._MISSIONDATABASE
_YAMCSINSTANCE.fields_by_name['processor'].message_type = _PROCESSORINFO
_YAMCSINSTANCE.fields_by_name['state'].enum_type = _YAMCSINSTANCE_INSTANCESTATE
_YAMCSINSTANCE_INSTANCESTATE.containing_type = _YAMCSINSTANCE
_PROCESSORINFO.fields_by_name['state'].enum_type = _SERVICESTATE
_PROCESSORINFO.fields_by_name['replayRequest'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYREQUEST
_PROCESSORINFO.fields_by_name['replayState'].enum_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYSTATUS_REPLAYSTATE
_PROCESSORINFO.fields_by_name['service'].message_type = _SERVICEINFO
_CLIENTINFO.fields_by_name['state'].enum_type = _CLIENTINFO_CLIENTSTATE
_CLIENTINFO_CLIENTSTATE.containing_type = _CLIENTINFO
_USERINFO.fields_by_name['clientInfo'].message_type = _CLIENTINFO
_USERINFO.fields_by_name['objectPrivilege'].message_type = _OBJECTPRIVILEGEINFO
_STATISTICS.fields_by_name['tmstats'].message_type = _TMSTATISTICS
_PROCESSORMANAGEMENTREQUEST.fields_by_name['operation'].enum_type = _PROCESSORMANAGEMENTREQUEST_OPERATION
_PROCESSORMANAGEMENTREQUEST_OPERATION.containing_type = _PROCESSORMANAGEMENTREQUEST
_PROCESSORREQUEST.fields_by_name['operation'].enum_type = _PROCESSORREQUEST_OPERATION
_PROCESSORREQUEST.fields_by_name['replaySpeed'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._REPLAYSPEED
_PROCESSORREQUEST_OPERATION.containing_type = _PROCESSORREQUEST
_LINKEVENT.fields_by_name['type'].enum_type = _LINKEVENT_TYPE
_LINKEVENT.fields_by_name['linkInfo'].message_type = _LINKINFO
_LINKEVENT_TYPE.containing_type = _LINKEVENT
_SERVICEINFO.fields_by_name['state'].enum_type = _SERVICESTATE
DESCRIPTOR.message_types_by_name['YamcsInstances'] = _YAMCSINSTANCES
DESCRIPTOR.message_types_by_name['YamcsInstance'] = _YAMCSINSTANCE
DESCRIPTOR.message_types_by_name['ProcessorInfo'] = _PROCESSORINFO
DESCRIPTOR.message_types_by_name['ClientInfo'] = _CLIENTINFO
DESCRIPTOR.message_types_by_name['ObjectPrivilegeInfo'] = _OBJECTPRIVILEGEINFO
DESCRIPTOR.message_types_by_name['UserInfo'] = _USERINFO
DESCRIPTOR.message_types_by_name['TmStatistics'] = _TMSTATISTICS
DESCRIPTOR.message_types_by_name['Statistics'] = _STATISTICS
DESCRIPTOR.message_types_by_name['ProcessorManagementRequest'] = _PROCESSORMANAGEMENTREQUEST
DESCRIPTOR.message_types_by_name['ProcessorRequest'] = _PROCESSORREQUEST
DESCRIPTOR.message_types_by_name['LinkInfo'] = _LINKINFO
DESCRIPTOR.message_types_by_name['LinkEvent'] = _LINKEVENT
DESCRIPTOR.message_types_by_name['ServiceInfo'] = _SERVICEINFO
DESCRIPTOR.enum_types_by_name['ServiceState'] = _SERVICESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YamcsInstances = _reflection.GeneratedProtocolMessageType('YamcsInstances', (_message.Message,), dict(
  DESCRIPTOR = _YAMCSINSTANCES,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.YamcsInstances)
  ))
_sym_db.RegisterMessage(YamcsInstances)

YamcsInstance = _reflection.GeneratedProtocolMessageType('YamcsInstance', (_message.Message,), dict(
  DESCRIPTOR = _YAMCSINSTANCE,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.YamcsInstance)
  ))
_sym_db.RegisterMessage(YamcsInstance)

ProcessorInfo = _reflection.GeneratedProtocolMessageType('ProcessorInfo', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSORINFO,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorInfo)
  ))
_sym_db.RegisterMessage(ProcessorInfo)

ClientInfo = _reflection.GeneratedProtocolMessageType('ClientInfo', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTINFO,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ClientInfo)
  ))
_sym_db.RegisterMessage(ClientInfo)

ObjectPrivilegeInfo = _reflection.GeneratedProtocolMessageType('ObjectPrivilegeInfo', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTPRIVILEGEINFO,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ObjectPrivilegeInfo)
  ))
_sym_db.RegisterMessage(ObjectPrivilegeInfo)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERINFO,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.UserInfo)
  ))
_sym_db.RegisterMessage(UserInfo)

TmStatistics = _reflection.GeneratedProtocolMessageType('TmStatistics', (_message.Message,), dict(
  DESCRIPTOR = _TMSTATISTICS,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.TmStatistics)
  ))
_sym_db.RegisterMessage(TmStatistics)

Statistics = _reflection.GeneratedProtocolMessageType('Statistics', (_message.Message,), dict(
  DESCRIPTOR = _STATISTICS,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.Statistics)
  ))
_sym_db.RegisterMessage(Statistics)

ProcessorManagementRequest = _reflection.GeneratedProtocolMessageType('ProcessorManagementRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSORMANAGEMENTREQUEST,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorManagementRequest)
  ))
_sym_db.RegisterMessage(ProcessorManagementRequest)

ProcessorRequest = _reflection.GeneratedProtocolMessageType('ProcessorRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSORREQUEST,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ProcessorRequest)
  ))
_sym_db.RegisterMessage(ProcessorRequest)

LinkInfo = _reflection.GeneratedProtocolMessageType('LinkInfo', (_message.Message,), dict(
  DESCRIPTOR = _LINKINFO,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.LinkInfo)
  ))
_sym_db.RegisterMessage(LinkInfo)

LinkEvent = _reflection.GeneratedProtocolMessageType('LinkEvent', (_message.Message,), dict(
  DESCRIPTOR = _LINKEVENT,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.LinkEvent)
  ))
_sym_db.RegisterMessage(LinkEvent)

ServiceInfo = _reflection.GeneratedProtocolMessageType('ServiceInfo', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEINFO,
  __module__ = 'yamcs.protobuf.yamcsManagement.yamcsManagement_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.yamcsManagement.ServiceInfo)
  ))
_sym_db.RegisterMessage(ServiceInfo)


DESCRIPTOR._options = None
_LINKINFO.fields_by_name['stream']._options = None
_LINKINFO.fields_by_name['dataCount']._options = None
# @@protoc_insertion_point(module_scope)
